==> haskell-hspec-wai-0.11.1-630-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-FDqg9kTkxQxF7GTPcn6I8S
key:                  hspec-wai-0.11.1-FDqg9kTkxQxF7GTPcn6I8S
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  29db5679e4de020cea3e44cd7cdf1c96
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-FDqg9kTkxQxF7GTPcn6I8S
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt text-2.0.2
    transformers-0.6.1.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-extra-3.1.18-1ANzYYqVephHj2C1lo6Zwk

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.11.1-632-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-4gP2lz7tZjUEFC03XYv0qO
key:                  hspec-wai-0.11.1-4gP2lz7tZjUEFC03XYv0qO
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  4fcc8b51714db940e073585411df9dcd
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-4gP2lz7tZjUEFC03XYv0qO
depends:
    QuickCheck-2.15.0.1-7BzLIlrrsyUAWv4ugiuXtJ base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    hspec-core-2.11.4-K7WhEYoVaEl4ISGwW2E5jD
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-types-0.12.4-2YF0olXF9itCctWavExzmH text-2.0.2
    transformers-0.6.1.0 wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    wai-extra-3.1.18-2NqKPuFl5Jd2v0if4D3Rrq

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
